function [alpha_trim, c_l_trim, c_d_trim] = trimtorange(range, alpha, c_l, c_d)
    % TRIMTORANGE Trims polars to a given range of angles of attack.
    % -----
    % (c) Copyright 2022 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % Apache 2.0 License
    % https://gitlab.uliege.be/am-dept/matlab_airfoil_toolbox

    % ----------------------------------------------------------------------------------------------

    narginchk(2, 4);
    for i = 1:size(alpha, 2)
        if nargin >= 3
            c_l_trim(:, i) = c_l(alpha(:, i) >= range(1) & alpha(:, i) <= range(end), i);
            if nargin == 4 && ~isempty(c_d)
                c_d_trim(:, i) = c_d(alpha(:, i) >= range(1) & alpha(:, i) <= range(end), i);
            else
                c_d_trim = [];
            end
        else
            nargoutchk(1, 1);
        end
        alpha_trim(:, i) = alpha(alpha(:, i) >= range(1) & alpha(:, i) <= range(end), i);
    end

    % If impossible to trim, just return the input
    if isempty(alpha_trim)
        alpha_trim = alpha;
        c_l_trim = c_l;
        c_d_trim = c_d;
    end

end
